@@ -14,9 +14,12 @@ declare(strict_types=1);
 
 namespace League\CommonMark\Tests\Functional\Extension\Attributes;
 
-use League\CommonMark\CommonMarkConverter;
-use League\CommonMark\Environment;
+use League\CommonMark\ConverterInterface;
+use League\CommonMark\Environment\Environment;
 use League\CommonMark\Extension\Attributes\AttributesExtension;
+use League\CommonMark\Extension\CommonMark\CommonMarkCoreExtension;
+use League\CommonMark\Extension\GithubFlavoredMarkdownExtension;
+use League\CommonMark\MarkdownConverter;
 use League\CommonMark\Tests\Functional\AbstractLocalDataTest;
 
 /**
@@ -24,28 +27,24 @@ use League\CommonMark\Tests\Functional\AbstractLocalDataTest;
  */
 final class LocalDataTest extends AbstractLocalDataTest
 {
-    protected function setUp(): void
-    {
-        $environment = Environment::createGFMEnvironment();
-        $environment->addExtension(new AttributesExtension());
-        $this->converter = new CommonMarkConverter([], $environment);
-    }
-
     /**
-     * @dataProvider dataProvider
+     * @param array<string, mixed> $config
      */
-    public function testRenderer(string $markdown, string $html, string $testName): void
+    protected function createConverter(array $config = []): ConverterInterface
     {
-        $this->assertMarkdownRendersAs($markdown, $html, $testName);
+        $environment = new Environment($config);
+        $environment->addExtension(new CommonMarkCoreExtension());
+        $environment->addExtension(new GithubFlavoredMarkdownExtension());
+        $environment->addExtension(new AttributesExtension());
+
+        return new MarkdownConverter($environment);
     }
 
     /**
-     * @return iterable<string, string, string>
+     * {@inheritDoc}
      */
     public function dataProvider(): iterable
     {
-        foreach ($this->loadTests(__DIR__ . '/data', '*.md') as $test) {
-            yield $test;
-        }
+        yield from $this->loadTests(__DIR__ . '/data');
     }
 }
